==> pslib_0.2.4.orig.tar.gz: pslib-0.2.4/src/ps_fontenc.c <==
#include "ps_intern.h"

ENCODING fontencoding = {
	"TeXBase1",
	{"", "dotaccent", "fi", "fl", "fraction", "hungarumlaut", "Lslash", "lslash",
	 "ogonek", "ring", "", "breve", "minus", "", "Zcaron", "zcaron",
	 "caron", "dotlessi", "dotlessj", "ff", "ffi", "ffl", "", "",
	 "", "", "", "", "", "", "grave", "quotesingle",
	 "space", "exclam", "quotedbl", "numbersign", "dollar", "percent", "ampersand", "quoteright",
	 "parenleft", "parenright", "asterisk", "plus", "comma", "hyphen", "period", "slash",
	 "zero", "one", "two", "three", "four", "five", "six", "seven",
	 "eight", "nine", "colon", "semicolon", "less", "equal", "greater", "question",
	 "at", "A", "B", "C", "D", "E", "F", "G",
	 "H", "I", "J", "K", "L", "M", "N", "O",
	 "P", "Q", "R", "S", "T", "U", "V", "W",
	 "X", "Y", "Z", "bracketleft", "backslash", "bracketright", "asciicircum", "underscore",
	 "quoteleft", "a", "b", "c", "d", "e", "f", "g",
	 "h", "i", "j", "k", "l", "m", "n", "o",
	 "p", "q", "r", "s", "t", "u", "v", "w",
	 "x", "y", "z", "braceleft", "bar", "braceright", "asciitilde", "",
	 "", "", "quotesinglbase", "florin", "quotedblbase", "ellipsis", "dagger", "daggerdbl",
	 "circumflex", "perthousand", "Scaron", "guilsinglleft", "OE", "", "", "",
	 "", "", "", "quotedblleft", "quotedblright", "bullet", "endash", "emdash",
	 "tilde", "trademark", "scaron", "guilsinglright", "oe", "", "", "Ydieresis",
	 "", "exclamdown", "cent", "sterling", "currency", "yen", "brokenbar", "section",
	 "dieresis", "copyright", "ordfeminine", "guillemotleft", "logicalnot", "hyphen", "registered", "macron",
	 "degree", "plusminus", "twosuperior", "threesuperior", "acute", "mu", "paragraph", "periodcentered",
	 "cedilla", "onesuperior", "ordmasculine", "guillemotright", "onequarter", "onehalf", "threequarters", "questiondown",
	 "Agrave", "Aacute", "Acircumflex", "Atilde", "Adieresis", "Aring", "AE", "Ccedilla",
	 "Egrave", "Eacute", "Ecircumflex", "Edieresis", "Igrave", "Iacute", "Icircumflex", "Idieresis",
	 "Eth", "Ntilde", "Ograve", "Oacute", "Ocircumflex", "Otilde", "Odieresis", "multiply",
	 "Oslash", "Ugrave", "Uacute", "Ucircumflex", "Udieresis", "Yacute", "Thorn", "germandbls",
	 "agrave", "aacute", "acircumflex", "atilde", "adieresis", "aring", "ae", "ccedilla",
	 "egrave", "eacute", "ecircumflex", "edieresis", "igrave", "iacute", "icircumflex", "idieresis",
	 "eth", "ntilde", "ograve", "", "oacute", "ocircumflex", "odieresis", "divide",
	 "oslash", "ugrave", "uacute", "ucircumflex", "udieresis", "yacute", "thorn", "ydieresis" } } ;

==> pslib_0.2.6.orig.tar.gz: pslib-0.2.6/src/ps_fontenc.c <==
#include "ps_intern.h"

ENCODING fontencoding = {
	"TeXBase1",
	{"", "dotaccent", "fi", "fl", "fraction", "hungarumlaut", "Lslash", "lslash",
	 "ogonek", "ring", "", "breve", "minus", "", "Zcaron", "zcaron",
	 "caron", "dotlessi", "dotlessj", "ff", "ffi", "ffl", "", "",
	 "", "", "", "", "", "", "grave", "quotesingle",
	 "space", "exclam", "quotedbl", "numbersign", "dollar", "percent", "ampersand", "quoteright",
	 "parenleft", "parenright", "asterisk", "plus", "comma", "hyphen", "period", "slash",
	 "zero", "one", "two", "three", "four", "five", "six", "seven",
	 "eight", "nine", "colon", "semicolon", "less", "equal", "greater", "question",
	 "at", "A", "B", "C", "D", "E", "F", "G",
	 "H", "I", "J", "K", "L", "M", "N", "O",
	 "P", "Q", "R", "S", "T", "U", "V", "W",
	 "X", "Y", "Z", "bracketleft", "backslash", "bracketright", "asciicircum", "underscore",
	 "quoteleft", "a", "b", "c", "d", "e", "f", "g",
	 "h", "i", "j", "k", "l", "m", "n", "o",
	 "p", "q", "r", "s", "t", "u", "v", "w",
	 "x", "y", "z", "braceleft", "bar", "braceright", "asciitilde", "",
	 "", "", "quotesinglbase", "florin", "quotedblbase", "ellipsis", "dagger", "daggerdbl",
	 "circumflex", "perthousand", "Scaron", "guilsinglleft", "OE", "", "", "",
	 "", "", "", "quotedblleft", "quotedblright", "bullet", "endash", "emdash",
	 "tilde", "trademark", "scaron", "guilsinglright", "oe", "", "", "Ydieresis",
	 "", "exclamdown", "cent", "sterling", "currency", "yen", "brokenbar", "section",
	 "dieresis", "copyright", "ordfeminine", "guillemotleft", "logicalnot", "hyphen", "registered", "macron",
	 "degree", "plusminus", "twosuperior", "threesuperior", "acute", "mu", "paragraph", "periodcentered",
	 "cedilla", "onesuperior", "ordmasculine", "guillemotright", "onequarter", "onehalf", "threequarters", "questiondown",
	 "Agrave", "Aacute", "Acircumflex", "Atilde", "Adieresis", "Aring", "AE", "Ccedilla",
	 "Egrave", "Eacute", "Ecircumflex", "Edieresis", "Igrave", "Iacute", "Icircumflex", "Idieresis",
	 "Eth", "Ntilde", "Ograve", "Oacute", "Ocircumflex", "Otilde", "Odieresis", "multiply",
	 "Oslash", "Ugrave", "Uacute", "Ucircumflex", "Udieresis", "Yacute", "Thorn", "germandbls",
	 "agrave", "aacute", "acircumflex", "atilde", "adieresis", "aring", "ae", "ccedilla",
	 "egrave", "eacute", "ecircumflex", "edieresis", "igrave", "iacute", "icircumflex", "idieresis",
	 "eth", "ntilde", "ograve", "oacute", "ocircumflex", "otilde", "odieresis", "divide",
	 "oslash", "ugrave", "uacute", "ucircumflex", "udieresis", "yacute", "thorn", "ydieresis" } } ;
